********************************************
*** 7th Doctoral Workshop DECOFIN ***
********************************************

* Seminario de introducción al uso de la Encuesta de Población Activa (EPA) en Stata

* Javier Garcia Clemente, email: javier.garcia@dege.uhu.es
* 15/07/2022


** Ejercicio práctico (desde cero) para aprender a explotar los microdatos EPA usando Stata:

****************************************************************************
************* PARTE 1: IMPORTACIÓN E INTRODUCCIÓN A LA EPA *****************
****************************************************************************

* 1. En la pág. web del Instituto Nacional de Estadística podemos encontrar toda la información relativa a esta encuesta. Descargaremos el último fichero de microdatos disponible y su diseño de registro en excel: INE --> Mercado Laboral --> Actividad, Ocupación y Paro --> Encuesta de Población Activa --> Resultados --> Microdatos. Enlace directo: https://ine.es/dyngs/INEbase/es/operacion.htm?c=Estadistica_C&cid=1254736176918&menu=resultados&idp=1254735976595#!tabs-1254736030639


* 2. En la carpeta descargada podemos encontrar el fichero de datos en diferentes extensiones: csv, txt, R, Stata, SPSS y SAS. En nuestro caso, podríamos usar directamente la versión de Stata, pero las variables las dan todas registradas como cadenas de caracteres y habría que transformarlas antes de trabajar. Por ello, optamos por leer el txt con nuestro diccionario que ya ajusta las variables a su formato e introduce descripción.

clear all
cap log close

cd "C:\Users\javga\OneDrive\Escritorio\seminarioEPA"  // Especificar ruta donde trabajamos

unzipfile "datos_1t22.zip"  , replace // Descomprimimos carpeta

* Podemos eliminar carpetas y archivos generados que no vamos a necesitar si se quiere
shell rd "SAS" "SPSS" "STATA" "R" "CSV" /s /q 
erase "Leeme.txt"

* Usamos diccionario para importar datos
infile using "dicc_EPA2021.dct"  , using("md_EPA_2022T1.txt")  

describe      // Descripción de variables


** El factor de elevación es un indicador del peso de cada observación muestral en el total de la población. factorel/100 representa el número de observaciones con esas características en la población.


***************** Ya podemos trabajar con este corte trimestral
compress
save "epa_1t2022.dta" , replace


****************************************************************************
************* PARTE 2: EJERCICIO PRÁCTICO CON MICRODATOS *****************
****************************************************************************

* 3. Supongamos que estamos interesados en estudiar la temporalidad en el mercado de trabajo español y su incidencia por sexo.
use "epa_1t2022.dta" , clear     // Cargamos datos

* Generamos nuestra variable objetivo "temp" para contratos temporales, en base a la información de ducon1
cap gen byte temp = 0 if ducon1==1
replace temp = 1 if ducon1==6
cap label var temp "Tiene contrato temporal"
cap label def temp 0"Indefinido" 1"Temporal"
cap label val temp temp

* Etiquetas sexo1
cap label def sexo1 1"Hombre" 6"Mujer"
cap label val sexo1 sexo1

* Veamos que ocurre con la temporalidad por sexo:
tab temp sexo1 , column chi2
tab temp sexo1 [iw=factorel/100] , column   // Con factor de elevación
* Parece que para las mujeres el % de temporalidad es más alto

* Haremos una regresión logística sencilla como ejemplo para estudiar el fenómeno, controlando por región y sector de actividad.
gen factorel100 = factorel/100  		// Transformamos el factor de elevación
svyset [iw=(factorel100)] 				// Especificamos los pesos a usar en la estimación
svy: logit temp i.sexo1 i.ccaa i.act 	// Estimamos el logit

margins, dydx(sexo1)    // Calculamos el efecto marginal medio de ser mujer sobre la probabilidad de tener un contrato temporal frente a uno indefinido. Resultado: tras controlar (solo) por región y sector de actividad, la probabilidad de ser temporal es 4.7 puntos superior en mujeres.

save , replace

****************************************************************************
************* PARTE 3: EXTRACCIÓN DE SERIES TEMPORALES *****************
****************************************************************************

* 4. Ahora supongamos que queremos extraer las series de trabajadores temporales por sexo desde el primer trimestre de 2021 hasta el último disponible para estudiar su evolución en los últimos trimestres. En primer lugar veremos como hacerlo para un corte (trimestre) concreto y luego generalizaremos el procedimiento.

use "epa_1t2022.dta" , clear     // Cargamos datos 1t2022

** Ordenamos las observaciones de la base de datos por sexo
sort sexo1

by sexo1: gen temp2 = sum(factorel100) if temp==1  // Sumamos individuos representados por el factor de elevación en aquellas observaciones que cumplen nuestra condición para cada sexo en este caso
by sexo1: list sexo1 temp factorel100 temp2 if _n>=_N-50				//	Esta orden muestra en pantalla las 50 últimas observaciones correspondientes a cada sexo

by sexo1: egen tempmax = max(temp2)		// Nos quedamos con el valor máximo por sexo, el acumulado
by sexo1: list sexo1 temp factorel100 temp2 tempmax if _n>=_N-50				//	Esta orden muestra en pantalla las 50 últimas observaciones correspondientes a cada sexo

by sexo1: keep if _n==_N		// Nos quedamos con el último valor, el acumulado para cada sexo
keep ciclo sexo1 tempmax 		// Y con las variables que necesitamos

*** Asignamos nombre, fecha y ordenamos
rename *max *
gen year = 2022
gen quarter = 1
order ciclo year quarter sexo1 temp

list 			// Resultado

* check INE: https://ine.es/jaxiT3/Tabla.htm?t=3961&L=0
* nota: la variable ducon1 solo contiene valores para asalariados (situ==7, situ==8)

*****************************************
* 5. La idea es hacer a continuación este mismo procedimiento de manera general para cualquier variable que queramos elevar y para cualquier periodo que queramos estudiar, obteniendo series "a demanda" a partir de una explotación de los microdatos EPA.

* Para ello, descargaremos los ficheros de microdatos desde 1t2021 hasta 4t2021. (https://ine.es/dyngs/INEbase/es/operacion.htm?c=Estadistica_C&cid=1254736176918&menu=resultados&idp=1254735976595#!tabs-1254736030639)

* Ahora debemos hacer la lectura de todos estos ficheros de manera equivalente a como trabajamos en la parte 1 del Do file, para luego extraer las series de manera análoga a como se ha hecho en la parte 3 del Do file. Los siguientes bucles automatizan este procedimiento:

*** BUCLE LECTURA EPA, METODOLOGÍA 2021T1 EN ADELANTE ***

clear all
cap log close

cd "C:\Users\javga\OneDrive\Escritorio\seminarioEPA"  // Especificar ruta donde trabajamos

local year 21 22					// Especificar años
local quarter 1 2 3 4 				// Especificar trimestres

foreach y in `year' {
	
	clear
	foreach q in `quarter' {
		
		clear
		cap noisily {            // Esto es por si no tengo todos los trimestre de un año 
		unzipfile "datos_`q't`y'.zip"  , replace // Descomprimimos carpeta

		* Podemos eliminar carpetas y archivos generados que no vamos a necesitar
		shell rd "SAS" "SPSS" "STATA" "R" "CSV" /s /q 
		erase "Leeme.txt"

		* Usamos diccionario para importar datos
		infile using "dicc_EPA2021.dct"  , using("md_EPA_20`y'T`q'.txt")  

		* Guardar corte trimestral
		compress
		save "epa_`q't20`y'.dta" , replace
		}
	}
}

***** BUCLE EXTRACCIÓN DE SERIES EPA, METODOLOGÍA 2021T1 EN ADELANTE ****

clear all
cap log close

cd "C:\Users\javga\OneDrive\Escritorio\seminarioEPA"  // Especificar ruta donde trabajamos

*
local variable temp				// Identificamos variable de interés
local grupos sexo1 				// Especificamos los grupos de interés
local year 21 22					// Especificar años
local quarter 1 2 3 4 				// Especificar trimestres

foreach y in `year' {
	
	clear
	foreach q in `quarter' {
		
		cap noisily {            // Esto es por si no tengo todos los trimestre de un año 
		use "epa_`q't20`y'.dta" , clear     // Cargamos datos 

		* Genero variables de interés
		cap gen byte temp = 1 if ducon1==6
		*gen paro=1 if aoi== 5 | aoi== 6

		** Ordenamos las observaciones de la base de datos por grupo
		sort `grupos'

		by `grupos': gen `variable'2 = sum(factorel/100) if `variable'==1  // Sumamos individuos representados por el factor de elevación en aquellas observaciones que cumplen nuestra condición para cada grupo

		by `grupos': egen `variable'max = max(`variable'2)		// Nos quedamos con el valor máximo por grupo, el acumulado

		* Eliminamos info restante
		by `grupos': keep if _n==_N		// Nos quedamos con el último valor, el acumulado para cada grupo
		keep ciclo `grupos' `variable'max 		// Y con las variables que necesitamos


		*** Asignamos nombre, fecha y ordenamos
		rename *max *
		gen year = 20`y'
		gen quarter = `q'
		order ciclo year quarter `grupos' `variable'
		
		** Guardamos explotación
		save "epa_`q't20`y'_`variable'_by`grupos'.dta" , replace
			
		}
	}
}

* Ahora construyo las series con los datos previamente extraídos

foreach y in `year' {
	foreach q in `quarter' {
		
		if `q' == 1 & `y' == 21 {
			use "epa_`q't20`y'_`variable'_by`grupos'.dta" , clear   // Cargo base inicial 2021t1
		}
		
		else {
			cap noisily {         // Esto es por si no tengo todos los trimestre de un año 
			append using "epa_`q't20`y'_`variable'_by`grupos'.dta"
			erase "epa_`q't20`y'_`variable'_by`grupos'.dta"
			}
		}	
	}
}

* Variable agrupada de tiempo y formatos
gen t = yq(year, quarter)
format t %tq
drop year quarter
order ciclo t `grupos' `variable'
sort `grupos' t

* Guardar base con la serie final y eliminar ficheros restantes
compress
save "epa_serie_`variable'_by`grupos'.dta"  , replace
erase "epa_1t2021_`variable'_by`grupos'.dta"

list
* check INE: https://ine.es/jaxiT3/Tabla.htm?t=3961&L=0

* Gráfico
xtset `grupos' t
xtline `variable' , overlay

* Excel
export excel using "series_`variable'_by`grupos'.xlsx", sheetreplace firstrow(variables)


**** EXTRA
* ¿Y si quisiera obtener estas series en un panel por provincia? 
* Otro ejemplo: ¿Y el número de parados por CCAA?...






